@@ -18,7 +18,7 @@
 
 #define EGG_CELL_RENDERER_TEXT_PATH "egg-cell-renderer-text"
 
-#define TOOLTIP_TEXT _("<New accelerator...>")
+#define TOOLTIP_TEXT _("New accelerator...")
 
 static void             egg_cell_renderer_keys_finalize      (GObject             *object);
 static void             egg_cell_renderer_keys_init          (EggCellRendererKeys *cell_keys);
@@ -424,12 +424,20 @@ grab_key_callback (GtkWidget    *widget,
                                         EGG_VIRTUAL_SCROLL_LOCK_MASK,
                                         &ignored_modifiers);
   
+  /* http://bugzilla.gnome.org/show_bug.cgi?id=139605
+   * mouse keys should effect keybindings */
+  ignored_modifiers |=	GDK_BUTTON1_MASK |
+			GDK_BUTTON2_MASK |
+			GDK_BUTTON3_MASK |
+			GDK_BUTTON4_MASK |
+			GDK_BUTTON5_MASK;
+
   /* filter consumed/ignored modifiers */
 
   if (keys->accel_mode == EGG_CELL_RENDERER_KEYS_MODE_GTK)
-    accel_mods = event->state & ~(consumed_modifiers | ignored_modifiers);
+    accel_mods = event->state & GDK_MODIFIER_MASK & ~(consumed_modifiers | ignored_modifiers);
   else if (keys->accel_mode == EGG_CELL_RENDERER_KEYS_MODE_X)
-    accel_mods = event->state & ~(ignored_modifiers);
+    accel_mods = event->state & GDK_MODIFIER_MASK & ~(ignored_modifiers);
   else
     g_assert_not_reached ();
     
@@ -450,9 +458,6 @@ grab_key_callback (GtkWidget    *widget,
 	  accel_keyval = 0;
 	  accel_mods = 0;
 	}
-
-      /* Remove modifiers like super and hyper, as GTK+ ignores them. */
-      accel_mods = accel_mods & GDK_MODIFIER_MASK;
     }
   
   edited = TRUE;
@@ -569,7 +574,7 @@ egg_cell_renderer_keys_start_editing (GtkCellRenderer      *cell,
 
   if (gdk_pointer_grab (widget->window, FALSE,
                         GDK_BUTTON_PRESS_MASK,
-                        FALSE, NULL,
+                        NULL, NULL,
                         gdk_event_get_time (event)) != GDK_GRAB_SUCCESS)
     {
       gdk_keyboard_ungrab (gdk_event_get_time (event));
